package com.zjsgfa.project.zjsgfa.service;

import java.util.Map;

import com.zjsgfa.project.zjsgfa.domain.SjZjyFdxnb;

/**
 * 设计信息-分段钻井液性能设计Service接口
 * 
 * @author
 * @date 2025-07-17
 */
public interface ISjZjyFdxnbService 
{
    /**
     * 查询设计信息-分段钻井液性能设计
     * 
     * @param id 设计信息-分段钻井液性能设计主键
     * @return 设计信息-分段钻井液性能设计
     */
    public SjZjyFdxnb selectSjZjyFdxnbById(Long id);

    /**
     * 查询设计信息-分段钻井液性能设计列表
     * 
     * @param sjZjyFdxnb 设计信息-分段钻井液性能设计
     * @return 设计信息-分段钻井液性能设计集合
     */
    public  Map<String, Object> selectSjZjyFdxnbList(SjZjyFdxnb sjZjyFdxnb);

    /**
     * 新增设计信息-分段钻井液性能设计
     * 
     * @param sjZjyFdxnb 设计信息-分段钻井液性能设计
     * @return 结果
     */
    public int insertSjZjyFdxnb(SjZjyFdxnb sjZjyFdxnb);

    /**
     * 修改设计信息-分段钻井液性能设计
     * 
     * @param sjZjyFdxnb 设计信息-分段钻井液性能设计
     * @return 结果
     */
    public int updateSjZjyFdxnb(SjZjyFdxnb sjZjyFdxnb);

    /**
     * 批量删除设计信息-分段钻井液性能设计
     * 
     * @param ids 需要删除的设计信息-分段钻井液性能设计主键集合
     * @return 结果
     */
    public int deleteSjZjyFdxnbByIds(Long[] ids);

    /**
     * 删除设计信息-分段钻井液性能设计信息
     * 
     * @param id 设计信息-分段钻井液性能设计主键
     * @return 结果
     */
    public int deleteSjZjyFdxnbById(Long id);




}
